<?php

namespace BrightRiver\Rendered\Block;

use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Catalog\Model\Product;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\View\Element\Template;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 * The button that triggers the 3D view popup to open.
 *
 * @since 1.0.0
 */
class Button extends Template
{
    /**
     * @var string
     */
    protected $_template = "button.phtml";

    /**
     * @var ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var null|Product
     */
    protected $product;

    /**
     * @var null|string
     */
    private $_clientID = null;

    /**
     * @var null|string
     */
    private $_productID = null;

    /**
     * @var null|string
     */
    private $_arPlacement = null;

    /**
     * @var null|string
     */
    private $_btnText = null;

    /**
     * @var null|string
     */
    private $_btnClasses = null;

    /**
     * @var null|string
     */
    private $_btnStyles = null;

    /**
     * @var null|string
     */
    private $_btnIcon = null;

    /**
     * @var null|string
     */
    private $_iconWidth = null;

    /**
     * @var null|string
     */
    private $_popupWidth = null;

    /**
     * @var null|string
     */
    private $_popupHeight = null;

    /**
     * @var null|string
     */
    private $_bgColor = null;

    /**
     * @var null|string
     */
    private $_arStatus = null;

    /**
     * @var null|string
     */
    private $_zoomStatus = null;

    /**
     * @var null|string
     */
    private $_autoRotate = null;

    /**
     * Button constructor.
     *
     * @param Template\Context $context
     * @param ProductRepositoryInterface $productRepository
     * @param RequestInterface $request
     * @param ScopeConfigInterface $scopeConfig
     * @param StoreManagerInterface $storeManager
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        ProductRepositoryInterface $productRepository,
        RequestInterface $request,
        ScopeConfigInterface $scopeConfig,
        StoreManagerInterface $storeManager,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->productRepository = $productRepository;
        $this->request = $request;
        $this->scopeConfig = $scopeConfig;
        $this->storeManager = $storeManager;
    }

    /**
     * Get the current product
     *
     * @return Product|null
     */
    public function getProduct()
    {
        if (!$this->product) {
            // Get product ID from the request parameters
            $productId = $this->getRequest()->getParam('id');

            // Load the product using the repository
            $this->product = $this->productRepository->getById($productId);
        }

        return $this->product;
    }

    /**
     * Get the "rendered_product_id" attribute value from the current product
     *
     * @return string|null
     */
    public function getProductID()
    {
        $product = $this->getProduct();

        if (!$this->_productID && $product) {
            $this->_productID = $product->getData('rendered_product_id');
        }

        return $this->_productID;
    }

    /**
     * Get the "rendered_ar_pacement" attribute value from the current product
     *
     * @return string|null
     */
    public function getARPlacement()
    {
        $product = $this->getProduct();

        if (!$this->_arPlacement && $product) {
            $arPlacement = $product->getData('rendered_ar_pacement');
            $this->_arPlacement = in_array($arPlacement, ['floor', 'wall']) ? $arPlacement : 'wall';
        }

        return $this->_arPlacement;
    }

    /**
     * Get the configured client ID for the products 3D asset
     *
     * @return string|null
     */
    public function getClientID()
    {
        if (!$this->_clientID) {
            $this->_clientID = $this->scopeConfig->getValue(
                'rendered/client_identity/client_id',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_clientID;
    }

    /**
     * Get the configured text for the button
     *
     * @return string|null
     */
    public function getButtonText()
    {
        if (!$this->_btnText) {
            $this->_btnText = $this->scopeConfig->getValue(
                'rendered/button/button_text',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_btnText;
    }

    /**
     * Get the configured class names for the button
     *
     * @return string|null
     */
    public function getButtonClass()
    {
        if (!$this->_btnClasses) {
            $this->_btnClasses = $this->scopeConfig->getValue(
                'rendered/button/button_classes',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_btnClasses;
    }

    /**
     * Get the configured custom styles for the button
     *
     * @return string|null
     */
    public function getButtonStyles()
    {
        if (!$this->_btnStyles) {
            $this->_btnStyles = $this->scopeConfig->getValue(
                'rendered/button/button_styles',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_btnStyles;
    }

    /**
     * Get the configured icon image URL for the button
     *
     * @return string|null
     */
    public function getButtonIcon()
    {
        if (!$this->_btnIcon) {
            $icon = $this->scopeConfig->getValue(
                'rendered/button/button_icon',
                ScopeInterface::SCOPE_STORE
            );

            if ($icon) {
                $baseUrl = $this->storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA);
                $this->_btnIcon = $baseUrl . 'BrightRiver/Rendered/icon/' . $icon;
            }
        }

        return $this->_btnIcon;
    }

    /**
     * Get the configured icon image width for the button
     *
     * @return string|null
     */
    public function getIconWidth()
    {
        if (!$this->_iconWidth) {
            $this->_iconWidth = $this->scopeConfig->getValue(
                'rendered/button/icon_width',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_iconWidth;
    }

    /**
     * Get the configured popup width
     *
     * @return string|null
     */
    public function getPopupWidth()
    {
        if (!$this->_popupWidth) {
            $this->_popupWidth = $this->scopeConfig->getValue(
                'rendered/popup/popup_width',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_popupWidth;
    }

    /**
     * Get the configured popup height
     *
     * @return string|null
     */
    public function getPopupHeight()
    {
        if (!$this->_popupHeight) {
            $this->_popupHeight = $this->scopeConfig->getValue(
                'rendered/popup/popup_height',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_popupHeight;
    }

    /**
     * Get the configured background color for the popup
     *
     * @return string|null
     */
    public function getBackgroundColor()
    {
        if (!$this->_bgColor) {
            $this->_bgColor = $this->scopeConfig->getValue(
                'rendered/popup/popup_bg',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_bgColor;
    }

    /**
     * Get the configured AR status for the popup
     *
     * @return string|null
     */
    public function getArStatus()
    {
        if (!$this->_arStatus) {
            $this->_arStatus = $this->scopeConfig->getValue(
                'rendered/popup/popup_ar',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_arStatus;
    }

    /**
     * Get the configured zoom status for the popup
     *
     * @return string|null
     */
    public function getZoomStatus()
    {
        if (!$this->_zoomStatus) {
            $this->_zoomStatus = $this->scopeConfig->getValue(
                'rendered/popup/popup_zoom',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_zoomStatus;
    }

    /**
     * Get the configured auto rotate status for the popup
     *
     * @return string|null
     */
    public function getAutoRotateStatus()
    {
        if (!$this->_autoRotate) {
            $this->_autoRotate = $this->scopeConfig->getValue(
                'rendered/popup/popup_rotate',
                ScopeInterface::SCOPE_STORE
            );
        }

        return $this->_autoRotate;
    }
}
